@@ -305,16 +305,19 @@ void MainWindow::BmePropertyModifiedSlot(QDBusMessage)
 
         if (!charging){
             if (m_PbCharge)
-                m_PbCharge->setValue(perc * 100);
+                m_PbCharge->SetValue(perc * 100);
             ui->lblPerc->setText(QString("%1%").arg(QString::number(perc, 'f', 1)));
         }
 
-        if (chargingChanged)
-            ProgressBarValueSlot(perc * 100);
+        if (chargingChanged && m_PbCharge)
+            m_PbCharge->SetValue(perc * 100);
         ui->lblCharge->setText(QString("%1 mAh").arg((int)current));
         ui->lblVoltage->setText(QString("%1 mV").arg((int)vcurrent));
         ui->lblRemaining->setText(CommonStatic::FormatHourMinutes(remainingSecs));
 
+        if (m_PbCharge)
+            m_PbCharge->SetIsCharging(charging);
+
         if (!charging){
             m_Timer->stop();
             if (perc < m_LastPercentage || m_LastPercentage == 0){
@@ -332,7 +335,7 @@ void MainWindow::BmePropertyModifiedSlot(QDBusMessage)
     }else{
         qWarning() << "Command returned" << proc->exitCode();
         if (m_PbCharge)
-            m_PbCharge->setValue(0);
+            m_PbCharge->SetValue(0);
         ui->lblPerc->setText(QString("%1%").arg(QString::number(0, 'f', 1)));
         ui->lblCharge->setText(QString("%1 mAh").arg(0));
         ui->lblVoltage->setText(QString("%1 mV").arg(0));
@@ -342,47 +345,6 @@ void MainWindow::BmePropertyModifiedSlot(QDBusMessage)
 #endif
 }
 
-void MainWindow::ProgressBarValueSlot(int value)
-{
-    if (m_PbCharge){
-        float perc = (float)value / 100.0;
-        if (!m_WasCharging)
-            m_PbCharge->setFormat(QString("%1%").arg(QString::number(perc, 'f', 1)));
-
-        QString style;
-
-        if (!m_WasCharging){
-            style = "QProgressBar:horizontal { \
-                       border: 0px transparent; \
-                       background: transparent; \
-                       text-align: center; \
-                     } ";
-        }else{
-            style = "QProgressBar:horizontal { \
-                       border: 0px transparent; \
-                       background: transparent; \
-                       text-align: center; \
-                       background-image: url(:/images/red.png); \
-                     } ";
-        }
-
-        if (perc >= 40.0 || m_WasCharging){
-            style.append("QProgressBar::chunk:horizontal {\
-                             background-image: url(:/images/green.png); \
-                          } ");
-        }else if (perc >= 20.0){
-            style.append("QProgressBar::chunk:horizontal {\
-                             background-image: url(:/images/orange.png); \
-                          } ");
-        }else{
-            style.append("QProgressBar::chunk:horizontal {\
-                             background-image: url(:/images/red.png); \
-                          } ");
-        }
-        m_PbCharge->setStyleSheet(style);
-    }
-}
-
 void MainWindow::ApplySettings()
 {
     m_LastPercentage = 0;
@@ -393,14 +355,17 @@ void MainWindow::ApplySettings()
         CommonStatic::CurrentSettings->PercStyle == Settings::StyleStandard) {
 
         if (m_PbCharge == NULL){
-            m_PbCharge = new QProgressBar(ui->frame);
-            m_PbCharge->setRange(0, 10000);
-            m_PbCharge->setValue(0);
-            m_PbCharge->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-            m_PbCharge->setTextVisible(true);
-            m_PbCharge->setContentsMargins(0,0,0,0);
+            m_PbCharge = new BatteryWidget(ui->frame);
+            m_PbCharge->SetBackgroundImage(QPixmap(":/images/battery.png"));
+            m_PbCharge->SetNormalLevelImage(QPixmap(":/images/green.png"));
+            m_PbCharge->SetLowLevelImage(QPixmap(":/images/orange.png"));
+            m_PbCharge->SetCriticalLevelImage(QPixmap(":/images/red.png"));
+            m_PbCharge->setFixedSize(166, 98);
+            m_PbCharge->SetRange(0, 10000);
+            m_PbCharge->SetInsideMargins(8, 8, 16, 8);
+            m_PbCharge->SetLevels(50, 30);
+            m_PbCharge->SetValue(0);
             ui->frame->layout()->addWidget(m_PbCharge);
-            connect(m_PbCharge, SIGNAL(valueChanged(int)), this, SLOT(ProgressBarValueSlot(int)));
         }
     }else{
         if (m_PbCharge){
@@ -420,15 +385,14 @@ void MainWindow::ApplySettings()
 
         qDebug() << "Percentage size:" << bkgSize.width() << "x" << bkgSize.height();
         ui->frame->setFixedSize(bkgSize);
-        ui->frame->setStyleSheet("QFrame { border-image: url(:/images/battery.png); }");
-        ui->frame->layout()->setContentsMargins(8, 8, 16, 8);
+        m_PbCharge->setFixedSize(bkgSize);
+        m_PbCharge->SetInsideMargins(8*CommonStatic::CurrentSettings->PercScale, 8*CommonStatic::CurrentSettings->PercScale, 16*CommonStatic::CurrentSettings->PercScale, 8*CommonStatic::CurrentSettings->PercScale);
     }else if (CommonStatic::CurrentSettings->PercStyle == Settings::StyleStandard){
         m_PbCharge->setFixedHeight(48);
         ui->lblPerc->setVisible(false);
         ui->frame->setVisible(true);
         ui->frame->setFixedSize(QWIDGETSIZE_MAX, QWIDGETSIZE_MAX);
         ui->frame->setStyleSheet("");
-        ui->frame->layout()->setContentsMargins(0,0,0,0);
     }else if (CommonStatic::CurrentSettings->PercStyle == Settings::StyleTextual){
         ui->lblPerc->setVisible(true);
         ui->frame->setVisible(false);
@@ -500,15 +464,14 @@ void MainWindow::SizeToFit()
 void MainWindow::ChargingTimerSlot()
 {
     if (m_PbCharge){
-        if (m_PbCharge->value() == m_PbCharge->maximum() || m_PbCharge->value() < m_LastPercentage * 100){
-            m_PbCharge->setValue(m_LastPercentage * 100);
-            m_PbCharge->setFormat(QString("%1%").arg(QString::number(m_LastPercentage, 'f', 1)));
+        if (m_PbCharge->Value() == m_PbCharge->Maximum() || m_PbCharge->Value() < m_LastPercentage * 100){
+            m_PbCharge->SetValue(m_LastPercentage * 100);
             ui->lblPerc->setText(tr("%1% Charging").arg(QString::number(m_LastPercentage, 'f', 1)));
         }else{
-            if (m_PbCharge->value() + 500 > m_PbCharge->maximum())
-                m_PbCharge->setValue(m_PbCharge->maximum());
+            if (m_PbCharge->Value() + 500 > m_PbCharge->Maximum())
+                m_PbCharge->SetValue(m_PbCharge->Maximum(), false);
             else
-                m_PbCharge->setValue(m_PbCharge->value() + 500);
+                m_PbCharge->SetValue(m_PbCharge->Value() + 500, false);
         }
     }
 }
@@ -531,12 +494,7 @@ float MainWindow::GetPowerConsumption()
 {
     float res = 0.0;
 
-    //From bq27200:
-    if (QFile::exists("/sys/class/power_supply/bq27200-0/current_now")){
-        qDebug() << "Getting power consumption from bq27200";
-        float curr = GetValue("/sys/class/power_supply/bq27200-0/current_now");
-        res =  curr * 3570.0 / 22.0 / 1000.0;
-    }else{
+    if (QFile::exists("/usr/sbin/i2cget")){
         //With i2cget:
         qDebug() << "Getting power consumption with i2cget";
         QProcess* proc = new QProcess(this);
@@ -555,6 +513,14 @@ float MainWindow::GetPowerConsumption()
         }
         delete proc;
     }
+
+    if (res == 0 && QFile::exists("/sys/class/power_supply/bq27200-0/current_now")){
+        //From bq27200:
+        qDebug() << "Getting power consumption from bq27200";
+        float curr = GetValue("/sys/class/power_supply/bq27200-0/current_now");
+        res =  curr * 3570.0 / 22.0 / 1000.0;
+    }
+
     return res;
 }
 
